@@ -34,6 +34,7 @@ from numba.cuda.core.ir_utils import (
 from numba.cuda.core.callconv import CUDACallConv
 
 from numba.cuda.core import postproc, rewrites, funcdesc, config
+from numba.cuda.core.options import InlineOptions
 
 
 try:
@@ -202,9 +203,15 @@ class BaseTypeInference(FunctionPass):
             'Function "%s" has invalid return type'
             % (state.func_id.func_name,),
         ):
-            legalize_return_type(
-                state.return_type, state.func_ir, state.targetctx
-            )
+            # We don't need to run legalize_return_type for always inline
+            # functions, as they will be inlined into their callers at numba IR
+            # stage and never compiled on their own. This allows us to support
+            # returning arrays that are not passed in as arguments, which is a
+            # common pattern in array-oriented code.
+            if state.flags.inline != InlineOptions("always"):
+                legalize_return_type(
+                    state.return_type, state.func_ir, state.targetctx
+                )
         return True
 
 
@@ -326,7 +333,7 @@ class BaseNativeLowering(abc.ABC, LoweringPass):
         metadata = state.metadata
         pre_stats = passmanagers.dump_refprune_stats()
 
-        call_conv = flags.call_conv
+        call_conv = state.call_conv
         if call_conv is None:
             call_conv = CUDACallConv(state.targetctx)
 
@@ -348,7 +355,7 @@ class BaseNativeLowering(abc.ABC, LoweringPass):
                     noalias=flags.noalias,
                     abi_tags=[flags.get_mangle_string()],
                     call_conv=call_conv,
-                    abi_info=flags.abi_info,
+                    abi_info=state.abi_info,
                 )
             )
 
