@@ -74,6 +74,15 @@ FROM_DTYPE = {
     np.dtype(object): types.pyobject,
 }
 
+# Optional dtype support (not provided by NumPy itself).
+try:
+    import ml_dtypes  # type: ignore
+except ImportError:
+    ml_dtypes = None
+
+if ml_dtypes is not None:
+    FROM_DTYPE[np.dtype(ml_dtypes.bfloat16)] = types.bfloat16
+
 re_typestr = re.compile(r"[<>=\|]([a-z])(\d+)?$", re.I)
 re_datetimestr = re.compile(r"[<>=\|]([mM])8?(\[([a-z]+)\])?$", re.I)
 
@@ -121,12 +130,31 @@ def _from_datetime_dtype(dtype):
         raise errors.NumbaNotImplementedError(dtype)
 
 
+def _dtype_cache_key(dtype):
+    """
+    Create a cache key for dtype that includes the isalignedstruct attribute.
+
+    NumPy's dtype hashing and comparison mechanisms do not consider the
+    isalignedstruct field when determining dtype equality. This means that
+    two dtypes with the same structure but different alignment settings would
+    be treated as identical by NumPy's default comparison, leading to incorrect
+    caching behavior. To ensure correct caching of from_dtype results, we
+    extend the cache key to explicitly include the isalignedstruct attribute.
+    """
+    return (
+        dtype,
+        getattr(dtype, "isalignedstruct", None),
+    )
+
+
 @functools.lru_cache
-def from_dtype(dtype):
+def _from_dtype_impl(dtype_cached):
     """
     Return a Numba Type instance corresponding to the given Numpy *dtype*.
     NumbaNotImplementedError is raised on unsupported Numpy dtypes.
     """
+    dtype = dtype_cached[0]
+
     if type(dtype) is type and issubclass(dtype, np.generic):
         dtype = np.dtype(dtype)
     elif getattr(dtype, "fields", None) is not None:
@@ -148,6 +176,10 @@ def from_dtype(dtype):
     raise errors.NumbaNotImplementedError(dtype)
 
 
+def from_dtype(dtype):
+    return _from_dtype_impl(_dtype_cache_key(dtype))
+
+
 _as_dtype_letters = {
     types.NPDatetime: "M8",
     types.NPTimedelta: "m8",
