@@ -37,7 +37,12 @@ def is_bfloat16_supported():
     return False
 
 
-class stream(object):
+def is_fp8_supported():
+    """FP8 is not hardware-accelerated in the simulator."""
+    return False
+
+
+class stream:
     """
     The stream API is supported in the simulator - however, all execution
     occurs synchronously, so synchronization requires no operation.
@@ -81,6 +86,7 @@ def detect():
     print("Found 1 CUDA devices")
     print("id %d    %20s %40s" % (0, "SIMULATOR", "[SUPPORTED]"))
     print("%40s: 5.0" % "compute capability")
+    print("%40s: No" % "FP8 Hardware Acceleration")
 
 
 def list_devices():
@@ -94,7 +100,7 @@ def get_current_device():
 # Events
 
 
-class Event(object):
+class Event:
     """
     The simulator supports the event API, but they do not record timing info,
     and all simulation is synchronous. Execution time is not recorded.
