@@ -27,7 +27,7 @@ def device_to_device(dst, src, size, stream=0):
     host_to_device(dst, src, size)
 
 
-class FakeDriver(object):
+class FakeDriver:
     def get_device_count(self):
         return 1
 
